--- otp_src_P9C_2003-07-25/lib/stdlib/src/erl_lint.erl	2003-07-28 08:17:10.000000000 +0200
+++ otp_src_P9C_2003-07-25.fixed/lib/stdlib/src/erl_lint.erl	2003-07-28 08:16:29.000000000 +0200
@@ -440,7 +440,12 @@
 behaviour_check(Bs, St) ->
     Mult = length(Bs) > 1,                      %More than one behaviour?
     foldl(fun ({Line,B}, St0) ->
-                  St1 = add_warning(Mult, Line, {several_behaviours,B}, St0),
+                  St1 = case supress_warn_several_behaviours(B, St0) of
+			    true ->
+				St0;
+			    _ ->
+				add_warning(Mult, Line, {several_behaviours,B}, St0)
+			end,
                   {Bfs, St2} = behaviour_callbacks(Line, B, St1),
                   Missing = ordsets:subtract(ordsets:from_list(Bfs),
                                              St2#lint.exports),
@@ -612,7 +617,12 @@
             St2 = St1#lint{defined=ordsets:add_element(NA, St1#lint.defined)},
             St = case erl_internal:bif(Name, Arity) of
                       true ->
-                         add_warning(Line, {redefine_bif,NA}, St2);
+			 case supress_warn_redefine_bif(NA, St2) of
+			     true ->
+				 St2;
+			     _ ->
+				 add_warning(Line, {redefine_bif,NA}, St2)
+			 end;
                      false -> St2
                   end,
             case imported(Name, Arity, St) of
@@ -1966,7 +1976,11 @@
     Arity = length(As),
     case otp_internal:obsolete(M, F, Arity) of
         {true, Info} ->
-            add_warning(Line, {obsolete, {M, F, Arity}, Info}, St);
+	    case supress_warn_obsolete({M, F, Arity}, St) of
+		true -> St;
+		_ ->
+		    add_warning(Line, {obsolete, {M, F, Arity}, Info}, St)
+	    end;
         false -> St
     end.
 
@@ -2169,3 +2183,29 @@
                     {error, St1}
             end
     end.
+
+supress_warn_redefine_bif(FA, St) ->
+    find_in_list(redefine_bif, FA, St#lint.compile).
+
+supress_warn_obsolete(MFA, St) ->
+    find_in_list(use_obsolete, MFA, St#lint.compile).
+
+supress_warn_several_behaviours(B, St) ->
+    lists:member(several_behaviours, St#lint.compile) or find_in_list(several_behaviours, B, St#lint.compile).
+    
+find_in_list(Tag, Arg, L) ->
+    {_, _, Res} = lists:foldl(fun({TTag, TArg}, {TTag, TArg,_TRes}) ->
+				      {TTag, TArg, true};
+				 ({TTag, TL}, A={TTag, TArg, _TRes}) when is_list(TL) ->
+				      case lists:member(TArg, TL) of
+					  true -> 
+					      {TTag, TArg, true};
+					  _ -> A
+				      end;
+				 (_, A) ->
+				      A
+			      end, {Tag, Arg, false}, L),
+    Res.
+
+				       
+							 
 				       
